pub struct LLToCore<T, C> { /* private fields */ }Expand description
Adapts an LL store to the Core Store interface.
This bridge:
- Converts
&[&[u8]]paths to validatedPath - Wraps returned bytes as
Record::Rawwith a format hint - Serializes
Recordto bytes for writes
Implementations
Sourceimpl<T, C> LLToCore<T, C>
impl<T, C> LLToCore<T, C>
Sourcepub fn new(inner: T, codec: C, format: Format) -> Self
pub fn new(inner: T, codec: C, format: Format) -> Self
Create a new bridge with the same format for reads and writes.
Sourcepub fn with_formats(
inner: T,
codec: C,
read_format: Format,
write_format: Format,
) -> Self
pub fn with_formats( inner: T, codec: C, read_format: Format, write_format: Format, ) -> Self
Create a new bridge with different formats for reads and writes.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Unwrap, returning the inner LL store.